Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(385)

Unified Diff: webrtc/modules/audio_processing/logging/apm_data_dumper.h

Issue 2300813004: Moved the place for the aec_debug_dump build flag and changed the name to apm_debug_dump (Closed)
Patch Set: Removed duplicate definition of build flag Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/modules/audio_processing/logging/apm_data_dumper.h
diff --git a/webrtc/modules/audio_processing/logging/apm_data_dumper.h b/webrtc/modules/audio_processing/logging/apm_data_dumper.h
index 230c6b3a3e5796c677dde4cc054d8a1a35210010..691c4cec5b6adfe56fe30d9c5ab9c0b66ba98590 100644
--- a/webrtc/modules/audio_processing/logging/apm_data_dumper.h
+++ b/webrtc/modules/audio_processing/logging/apm_data_dumper.h
@@ -22,14 +22,14 @@
#include "webrtc/common_audio/wav_file.h"
// Check to verify that the define is properly set.
-#if !defined(WEBRTC_AEC_DEBUG_DUMP) || \
- (WEBRTC_AEC_DEBUG_DUMP != 0 && WEBRTC_AEC_DEBUG_DUMP != 1)
-#error "Set WEBRTC_AEC_DEBUG_DUMP to either 0 or 1"
+#if !defined(WEBRTC_APM_DEBUG_DUMP) || \
+ (WEBRTC_APM_DEBUG_DUMP != 0 && WEBRTC_APM_DEBUG_DUMP != 1)
+#error "Set WEBRTC_APM_DEBUG_DUMP to either 0 or 1"
#endif
namespace webrtc {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
// Functor used to use as a custom deleter in the map of file pointers to raw
// files.
struct RawFileCloseFunctor {
@@ -50,7 +50,7 @@ class ApmDataDumper {
// Reinitializes the data dumping such that new versions
// of all files being dumped to are created.
void InitiateNewSetOfRecordings() {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
++recording_set_index_;
#endif
}
@@ -58,20 +58,20 @@ class ApmDataDumper {
// Methods for performing dumping of data of various types into
// various formats.
void DumpRaw(const char* name, int v_length, const float* v) {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
FILE* file = GetRawFile(name);
fwrite(v, sizeof(v[0]), v_length, file);
#endif
}
void DumpRaw(const char* name, rtc::ArrayView<const float> v) {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
DumpRaw(name, v.size(), v.data());
#endif
}
void DumpRaw(const char* name, int v_length, const bool* v) {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
FILE* file = GetRawFile(name);
for (int k = 0; k < v_length; ++k) {
int16_t value = static_cast<int16_t>(v[k]);
@@ -81,33 +81,33 @@ class ApmDataDumper {
}
void DumpRaw(const char* name, rtc::ArrayView<const bool> v) {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
DumpRaw(name, v.size(), v.data());
#endif
}
void DumpRaw(const char* name, int v_length, const int16_t* v) {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
FILE* file = GetRawFile(name);
fwrite(v, sizeof(v[0]), v_length, file);
#endif
}
void DumpRaw(const char* name, rtc::ArrayView<const int16_t> v) {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
DumpRaw(name, v.size(), v.data());
#endif
}
void DumpRaw(const char* name, int v_length, const int32_t* v) {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
FILE* file = GetRawFile(name);
fwrite(v, sizeof(v[0]), v_length, file);
#endif
}
void DumpRaw(const char* name, rtc::ArrayView<const int32_t> v) {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
DumpRaw(name, v.size(), v.data());
#endif
}
@@ -117,7 +117,7 @@ class ApmDataDumper {
const float* v,
int sample_rate_hz,
int num_channels) {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
WavWriter* file = GetWavFile(name, sample_rate_hz, num_channels);
file->WriteSamples(v, v_length);
#endif
@@ -127,13 +127,13 @@ class ApmDataDumper {
rtc::ArrayView<const float> v,
int sample_rate_hz,
int num_channels) {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
DumpWav(name, v.size(), v.data(), sample_rate_hz, num_channels);
#endif
}
private:
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
const int instance_index_;
int recording_set_index_ = 0;
std::unordered_map<std::string, std::unique_ptr<FILE, RawFileCloseFunctor>>
« no previous file with comments | « webrtc/modules/audio_processing/audio_processing.gypi ('k') | webrtc/modules/audio_processing/logging/apm_data_dumper.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698